Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(533)

Unified Diff: chrome/browser/chromeos/arc/fileapi/arc_content_file_system_backend_delegate.h

Issue 2411323002: arc: Empty implementation of ARC content file system (Closed)
Patch Set: Address comments Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/arc/fileapi/arc_content_file_system_backend_delegate.h
diff --git a/chrome/browser/chromeos/drive/fileapi/file_system_backend_delegate.h b/chrome/browser/chromeos/arc/fileapi/arc_content_file_system_backend_delegate.h
similarity index 61%
copy from chrome/browser/chromeos/drive/fileapi/file_system_backend_delegate.h
copy to chrome/browser/chromeos/arc/fileapi/arc_content_file_system_backend_delegate.h
index 6ac4027e6a168b1119176c81f936ed6cb0193be4..66a6503dd392978cef5bdc2a28c3f489559d5b26 100644
--- a/chrome/browser/chromeos/drive/fileapi/file_system_backend_delegate.h
+++ b/chrome/browser/chromeos/arc/fileapi/arc_content_file_system_backend_delegate.h
@@ -1,34 +1,24 @@
-// Copyright 2014 The Chromium Authors. All rights reserved.
+// Copyright 2016 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_CHROMEOS_DRIVE_FILEAPI_FILE_SYSTEM_BACKEND_DELEGATE_H_
-#define CHROME_BROWSER_CHROMEOS_DRIVE_FILEAPI_FILE_SYSTEM_BACKEND_DELEGATE_H_
-
-#include <stdint.h>
+#ifndef CHROME_BROWSER_CHROMEOS_ARC_FILEAPI_ARC_CONTENT_FILE_SYSTEM_BACKEND_DELEGATE_H_
+#define CHROME_BROWSER_CHROMEOS_ARC_FILEAPI_ARC_CONTENT_FILE_SYSTEM_BACKEND_DELEGATE_H_
#include <memory>
#include "base/macros.h"
#include "chrome/browser/chromeos/fileapi/file_system_backend_delegate.h"
-namespace storage {
-class AsyncFileUtil;
-class FileSystemContext;
-class FileStreamReader;
-class FileSystemURL;
-class FileStreamWriter;
-class WatcherManager;
-} // namespace storage
-
-namespace drive {
+namespace arc {
// Delegate implementation of the some methods in chromeos::FileSystemBackend
-// for Drive file system.
-class FileSystemBackendDelegate : public chromeos::FileSystemBackendDelegate {
+// for ARC content file system.
+class ArcContentFileSystemBackendDelegate
+ : public chromeos::FileSystemBackendDelegate {
public:
- FileSystemBackendDelegate();
- ~FileSystemBackendDelegate() override;
+ ArcContentFileSystemBackendDelegate();
+ ~ArcContentFileSystemBackendDelegate() override;
// FileSystemBackend::Delegate overrides.
storage::AsyncFileUtil* GetAsyncFileUtil(
@@ -51,9 +41,9 @@ class FileSystemBackendDelegate : public chromeos::FileSystemBackendDelegate {
private:
std::unique_ptr<storage::AsyncFileUtil> async_file_util_;
- DISALLOW_COPY_AND_ASSIGN(FileSystemBackendDelegate);
+ DISALLOW_COPY_AND_ASSIGN(ArcContentFileSystemBackendDelegate);
};
-} // namespace drive
+} // namespace arc
-#endif // CHROME_BROWSER_CHROMEOS_DRIVE_FILEAPI_FILE_SYSTEM_BACKEND_DELEGATE_H_
+#endif // CHROME_BROWSER_CHROMEOS_ARC_FILEAPI_ARC_CONTENT_FILE_SYSTEM_BACKEND_DELEGATE_H_

Powered by Google App Engine
This is Rietveld 408576698